@@ -4,6 +4,7 @@
 #' @include lexicon_afinn.R lexicon_loughran.R lexicon_bing.R lexicon_nrc.R
 #' @include dataset_sentence_polarity.R dataset_ag_news.R dataset_dbpedia.R
 #' @include dataset_trec.R dataset_imdb.R lexicon_nrc_eil.R lexicon_nrc_vad.R
+#' @include embedding_glove.R
 #' @noRd
 "download_functions"
 download_functions <- list(
@@ -17,5 +18,9 @@ download_functions <- list(
   ag_news = download_ag_news,
   dbpedia = download_dbpedia,
   trec = download_trec,
-  imdb = download_imdb
+  imdb = download_imdb,
+  glove6b = download_glove6b,
+  glove27b = download_glove27b,
+  glove42b = download_glove42b,
+  glove840b = download_glove840b
 )
